pub struct Pixel {
pub date: String,
pub quantity: String,
}Expand description
Data representing the quantity of each day.
Fields
date: StringThe date on which the quantity is to be recorded. It is specified in yyyyMMdd format.
quantity: StringSpecify the quantity to be registered on the specified date. Validation rule: int^-?[0-9]+ float^-?[0-9]+.[0-9]+